import { Construct } from 'constructs';
import { UserPoolIdentityProviderProps } from './base';
import { UserPoolIdentityProviderBase } from './private/user-pool-idp-base';
/**
 * Properties to initialize UserPoolGoogleIdentityProvider.
 *
 * @stability stable
 */
export interface UserPoolIdentityProviderGoogleProps extends UserPoolIdentityProviderProps {
    /**
     * The client id recognized by Google APIs.
     *
     * @see https://developers.google.com/identity/sign-in/web/sign-in#specify_your_apps_client_id
     * @stability stable
     */
    readonly clientId: string;
    /**
     * The client secret to be accompanied with clientId for Google APIs to authenticate the client.
     *
     * @see https://developers.google.com/identity/sign-in/web/sign-in
     * @stability stable
     */
    readonly clientSecret: string;
    /**
     * The list of google permissions to obtain for getting access to the google profile.
     *
     * @default [ profile ]
     * @see https://developers.google.com/identity/sign-in/web/sign-in
     * @stability stable
     */
    readonly scopes?: string[];
}
/**
 * Represents a identity provider that integrates with 'Google'.
 *
 * @stability stable
 * @resource AWS::Cognito::UserPoolIdentityProvider
 */
export declare class UserPoolIdentityProviderGoogle extends UserPoolIdentityProviderBase {
    /**
     * The primary identifier of this identity provider.
     *
     * @stability stable
     */
    readonly providerName: string;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: UserPoolIdentityProviderGoogleProps);
}
